<?php

/*
 * This file is part of the FOSUserBundle package.
 *
 * (c) FriendsOfSymfony <http://friendsofsymfony.github.com/>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace FOS\UserBundle\Controller;

use FOS\UserBundle\Event\FilterUserResponseEvent;
use FOS\UserBundle\Event\FormEvent;
use FOS\UserBundle\Event\GetResponseUserEvent;
use FOS\UserBundle\Form\Factory\FactoryInterface;
use FOS\UserBundle\FOSUserEvents;
use FOS\UserBundle\Model\UserInterface;
use FOS\UserBundle\Model\UserManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;

/**
 * Controller managing the user profile.
 *
 * @author Christophe Coevoet <stof@notk.org>
 */
class ProfileController extends Controller
{
    /**
     * Show the user.
     */
    public function showAction()
    {
        $user = $this->getUser();
        if (!is_object($user) || !$user instanceof UserInterface) {
            throw new AccessDeniedException('This user does not have access to this section.');
        }

        return $this->render('@FOSUser/Profile/show.html.twig', array(
            'user' => $user,
        ));
    }

    /**
     * Edit the user.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function editAction(Request $request)
    {
        if(sizeof($request->query)!=0) {
            $this->get('session')->set('user', $request->query->get('user'));
        }
        $em = $this->get('doctrine.orm.entity_manager');
        if(sizeof($request->query)!=0){
            $this->get('session')->set('displayAgent', $request->query->get('displayAgent'));
            $this->get('session')->set('displayEtudiant', $request->query->get('displayEtudiant'));
            $this->get('session')->set('displayEnseignant', $request->query->get('displayEnseignant'));
        }
        $displayAgent=$this->get('session')->get('displayAgent');
        $displayEtudiant=$this->get('session')->get('displayEtudiant');
        $displayEnseignant=$this->get('session')->get('displayEnseignant');
        $user = $em->getRepository('AppBundle:User')->find( intval($this->get('session')->get('user')));
        if (!is_object($user) || !$user instanceof UserInterface) {
            throw new AccessDeniedException('This user does not have access to this section.');
        }

        /** @var $dispatcher EventDispatcherInterface */
        $dispatcher = $this->get('event_dispatcher');

        $event = new GetResponseUserEvent($user, $request);
        $dispatcher->dispatch(FOSUserEvents::PROFILE_EDIT_INITIALIZE, $event);

        if (null !== $event->getResponse()) {
            return $event->getResponse();
        }

        /** @var $formFactory FactoryInterface */
        $formFactory = $this->get('fos_user.profile.form.factory');

        $form = $formFactory->createForm();
        $form->setData($user);
        $path=$user->getPath();
        $form->handleRequest($request);
        if ($form->isSubmitted()) {
            /** @var $userManager UserManagerInterface */
            $userManager = $this->get('fos_user.user_manager');
            $event = new FormEvent($form, $request);
            $dispatcher->dispatch(FOSUserEvents::PROFILE_EDIT_SUCCESS, $event);
            $role=$this->container->getParameter('security.role_hierarchy.roles');
            /*if($user->hasRole($role['ROLE_ETUDIANT'][0]) || $user->hasRole($role['ROLE_ENSEIGNANT'][0])){
                $classes=$user->getUserClasse();
                foreach($classes as $classe){
                    $user->removeUserClasse($classe);
                }
                if($user->getClasse()){
                    $cla=$user->getClasse();
                    $user->addUserClasse($cla);
                }
            }*/
            $file = $user->getFile();
            if($file!=null)
            {
                $fileName = md5(uniqid()).'.'.$file->guessExtension();
                // Move the file to the directory where brochures are stored
                $file->move($this->container->getParameter('kernel.root_dir').'/../web/image/user',
                    $fileName
                );
                $user->setPath($fileName);
                $user->setFile(null);
            }
            $userManager->updateUser($user);

            if (null === $response = $event->getResponse()) {
                $url = $this->generateUrl('fos_user_profile_show');
                $response = new RedirectResponse($url);
            }

            $dispatcher->dispatch(FOSUserEvents::PROFILE_EDIT_COMPLETED, new FilterUserResponseEvent($user, $request, $response));


                    return $this->redirectToRoute("mfmm_crm_annee_to_etudiants");
        }

        return $this->render('@FOSUser/Profile/edit.html.twig', array(
            'form' => $form->createView(),'displayAgent'=>$displayAgent,'displayEnseignant'=>$displayEnseignant,'displayEtudiant'=>$displayEtudiant,'path'=>$path,'id'=>$user->getId()
        ));
    }
}
